@@ -4,7 +4,7 @@
  * Implementation of the part of the TclCurl extension that deals with libcurl's
  * 'multi' interface.
  *
- * Copyright (c)2002-2004 Andrs Garca Garca.
+ * Copyright (c)2002-2005 Andrs Garca Garca.
  *
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
@@ -152,7 +152,6 @@ curlMultiObjCmd (ClientData clientData, Tcl_Interp *interp,
 
     struct curlMultiObjData    *curlMultiData=(struct curlMultiObjData *)clientData;
     CURLMcode                   errorCode;
-    Tcl_Command                 cmdToken=curlMultiData->token;
     int                         tableIndex;
 
     if (objc<2) {
@@ -180,7 +179,7 @@ curlMultiObjCmd (ClientData clientData, Tcl_Interp *interp,
             return errorCode;
             break;
         case 3:
-            fprintf(stdout,"Multi cleanup\n");
+/*            fprintf(stdout,"Multi cleanup\n"); */
             Tcl_DeleteCommandFromToken(interp,curlMultiData->token);
             break;
         case 4:
@@ -728,7 +727,6 @@ curlEventSetup(ClientData clientData, int flags) {
 void
 curlEventCheck(ClientData clientData, int flags) {
     struct curlMultiObjData    *curlMultiData=(struct curlMultiObjData *)clientData;
-    Tcl_Event                  *eventToInvokePtr;
     struct curlEvent           *curlEventPtr;
     int                         selectCode;
 
