@@ -4,7 +4,7 @@
  * Header file for the part of the TclCurl extension that deals with libcurl's
  * 'multi' interface.
  *
- * Copyright (c) 2002-2004 Andrs Garca Garca.
+ * Copyright (c) 2002-2005 Andrs Garca Garca.
  *
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
@@ -13,6 +13,9 @@
 
 #include "tclcurl.h"
 
+#define _MPRINTF_REPLACE
+#include <curl/mprintf.h>
+
 #ifdef  __cplusplus
 extern "C" {
 #endif 
