@@ -1,16 +1,20 @@
 /*
  * tclcurl.h --
  *
- * Header file for the TclCurl extension to enable Tcl interpreters 
+ * Header file for the TclCurl extension to enable Tcl interpreters
  * to access libcurl.
  *
- * Copyright (c) 2001-2004 Andrs Garca Garca.
+ * Copyright (c) 2001-2005 Andrs Garca Garca.
  *
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
  */
 
+#if (defined(WIN32) || defined(_WIN32))
+#define CURL_STATICLIB 1
+#endif
+
 #include <curl/curl.h>
 #include <curl/types.h>
 #include <curl/easy.h>
@@ -19,12 +23,12 @@
 #include <stdio.h>
 #include <string.h>
 
-#define _MPRINTF_REPLACE 
+#define _MPRINTF_REPLACE
 #include <curl/mprintf.h>
 
 #ifdef  __cplusplus
 extern "C" {
-#endif 
+#endif
 
 /*
  * Windows needs to know which symbols to export.  Unix does not.
@@ -34,11 +38,11 @@ extern "C" {
  */
 
 #ifdef BUILD_tclcurl
-#undef TCL_STORAGE_CLASS
+#undef  TCL_STORAGE_CLASS
 #define TCL_STORAGE_CLASS DLLEXPORT
 #endif
 
-#define TclCurlVersion "0.12.2"
+#define TclCurlVersion "0.13.2"
 
 /*
  * This struct will contain the data of a transfer if the user wants
@@ -119,11 +123,13 @@ struct curlObjData {
     struct curl_slist    *http200aliases;
     char                 *command;
     char                 *netrcfile;
-    char                 *sourceHost;
+    char                 *sourceUrl;
     char                 *sourceUserPwd;
-    char                 *sourcePath;
     struct curl_slist    *sourcePreQuote;
+    struct curl_slist    *sourceQuote;
     struct curl_slist    *sourcePostQuote;
+    char                 *ftpAccount;
+    int                   anyAuthFlag;
 };
 
 struct shcurlObjData {
@@ -181,7 +187,8 @@ static CONST char *optionTable[] = {
     "CURLOPT_AUTOREFERER",    "CURLOPT_SOURCE_HOST",   "CURLOPT_SOURCE_USERPWD",
     "CURLOPT_SOURCE_PATH",    "CURLOPT_SOURCE_PORT",   "CURLOPT_PASV_HOST",
     "CURLOPT_SOURCE_PREQUOTE","CURLOPT_SOURCE_POSTQUOTE",
-    "CURLOPT_FTPSSLAUTH",
+    "CURLOPT_FTPSSLAUTH",     "CURLOPT_SOURCE_URL",    "CURLOPT_SOURCE_QUOTE",
+    "CURLOPT_FTP_ACCOUNT",
     (char *) NULL
 };
 
@@ -223,7 +230,8 @@ static CONST char *configTable[] = {
     "-share",             "-port",               "-tcpnodelay",
     "-autoreferer",       "-sourcehost",         "-sourceuserpwd",
     "-sourcepath",        "-sourceport",         "-pasvhost",
-    "-sourceprequote",    "-sourceposrquote",    "-ftpsslauth",
+    "-sourceprequote",    "-sourcepostquote",    "-ftpsslauth",
+    "-sourceurl",         "-sourcequote",        "-ftpaccount",
     (char *) NULL
 };
 
@@ -246,7 +254,8 @@ static CONST char    *getInfoTable[]={
     "contentlengthdownload",            "contentlengthupload",
     "starttransfertime",                "contenttype",
     "redirecttime",   "redirectcount",  "httpauthavail",
-    "proxyauthavail", "oserrno",
+    "proxyauthavail", "oserrno",        "numconnects",
+    "sslengines",     "httpconnectcode",
     (char *) NULL
 };
 
@@ -376,6 +385,8 @@ int curlOpenFile(Tcl_Interp *interp,char *fileName, FILE **handle, int writing,
 int  curlOpenFiles (Tcl_Interp *interp,struct curlObjData *curlData);
 void curlCloseFiles(struct curlObjData *curlData);
 
+static curlioerr curlioctl(CURL *handle, curliocmd cmd, void *userp);
+
 int curlSetPostData(Tcl_Interp *interp,struct curlObjData *curlData);
 void curlResetPostData(struct curlObjData *curlDataPtr);
 void curlResetFormArray(struct curl_forms *formArray);
@@ -388,7 +399,7 @@ char *curlstrdup (char *old);
 char *curlCreateShareObjCmd (Tcl_Interp *interp,struct shcurlObjData  *shcurlData);
 int curlShareInitObjCmd (ClientData clientData, Tcl_Interp *interp,
         int objc,Tcl_Obj *CONST objv[]);
-int curlShareObjCmd (ClientData clientData, Tcl_Interp *interp, 
+int curlShareObjCmd (ClientData clientData, Tcl_Interp *interp,
         int objc,Tcl_Obj *CONST objv[]);
 int curlCleanUpShareCmd(ClientData clientData);
 
