@@ -1,6 +1,8 @@
 package require TclCurl
 
-puts "El fichero: [file exists /home/andres/.getleft/cookies]"
+if {![file exists /home/andres/.getleft/cookies]} {
+    puts "The given cookie file doesn't exists"
+}
 
 curl::transfer -url 127.0.0.1 \
         -cookiefile "/home/andres/.getleft/cookies" -verbose 1
