@@ -6,6 +6,7 @@ $curlHandle perform
 
 puts "Url: [$curlHandle getinfo effectiveurl]"
 puts "Http-code: [$curlHandle getinfo responsecode]"
+puts "Proxy response code: [$curlHandle getinfo httpconnectcode]"
 set fileTime [$curlHandle getinfo filetime]
 puts "Filetime: $fileTime - [clock format $fileTime]"
 puts "Total time: [$curlHandle getinfo totaltime]"
@@ -20,6 +21,7 @@ puts "Name speed upload: [$curlHandle getinfo speedupload]"
 puts "Name header size: [$curlHandle getinfo headersize]"
 puts "Name request size: [$curlHandle getinfo requestsize]"
 puts "Name ssl verifyresult: [$curlHandle getinfo sslverifyresult]"
+puts "SSL engines: [$curlHandle getinfo sslengines]"
 puts "Name length download: [$curlHandle getinfo contentlengthdownload]"
 puts "Name length upload: [$curlHandle getinfo contentlengthupload]"
 puts "Content-Type: [$curlHandle getinfo contenttype]"
@@ -28,6 +30,7 @@ puts "Redirect count: [$curlHandle getinfo redirectcount]"
 puts "Authentication methods available: [$curlHandle getinfo httpauthavail]"
 puts "Authentication methods at the proxy: [$curlHandle getinfo proxyauthavail]"
 puts "Operating System error number: [$curlHandle getinfo oserrno]"
+puts "Number of successful connects: [$curlHandle getinfo numconnects]"
 
 $curlHandle cleanup
 
